==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-solvers/Concrete/EpetraTSFOperator.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef EPETRA_TSFOPERATOR_HPP
#define EPETRA_TSFOPERATOR_HPP

#include "TSFLinearOperatorImpl.hpp"
#include "TSFLinearSolver.hpp"
#include "Epetra_Operator.h"
#include "TSFVectorSpace2EpetraMap.hpp"

namespace Epetra
{
  using namespace Teuchos;
  using namespace Thyra;
  using namespace TSFExtended;

  /** */
  class Epetra_TSFOperator : public Epetra_Operator
  {
  public:
    /** */
    Epetra_TSFOperator(const LinearOperator<double>& A,
		       const LinearSolver<double>& solver=LinearSolver<double>());
    
    /** */
    int SetUseTranspose(bool useTrans) {useTranspose_ = useTrans; return 0;}

    /** */
    int Apply(const Epetra_MultiVector& in, Epetra_MultiVector& out) const ;

    /** */
    int ApplyInverse(const Epetra_MultiVector& in, Epetra_MultiVector& out) const ;

    /** */
    double NormInf() const ;

    /** */
    const char* Label() const ;

    /** */
    bool UseTranspose() const {return useTranspose_;}

    /** */
    bool HasNormInf() const {return false;}

    /** */
    const Epetra_Comm& Comm() const {return *comm_;}

    /** */
    const Epetra_Map& OperatorDomainMap() const {return *domain_;}

    /** */
    const Epetra_Map& OperatorRangeMap() const {return *range_;}

    

  private:
    LinearOperator<double> A_;
    LinearSolver<double> solver_;
    bool useTranspose_;
    RefCountPtr<Epetra_Comm> comm_;
    RefCountPtr<const Epetra_Map> domain_;
    RefCountPtr<const Epetra_Map> range_;
    bool isNativeEpetra_;
    bool isCompoundEpetra_;
    string label_;
  };
}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Concrete/EpetraTSFOperator.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef EPETRA_TSFOPERATOR_HPP
#define EPETRA_TSFOPERATOR_HPP

#include "TSFLinearOperatorDecl.hpp"
#include "TSFLinearSolverDecl.hpp"
#include "Epetra_Operator.h"
#include "TSFVectorSpace2EpetraMap.hpp"

namespace Epetra
{
  using namespace Teuchos;
  using namespace Thyra;
  

  /** */
  class Epetra_TSFOperator : public Epetra_Operator
  {
  public:
    /** */
    Epetra_TSFOperator(const LinearOperator<double>& A,
		       const LinearSolver<double>& solver=LinearSolver<double>());
    
    /** */
    int SetUseTranspose(bool useTrans) {useTranspose_ = useTrans; return 0;}

    /** */
    int Apply(const Epetra_MultiVector& in, Epetra_MultiVector& out) const ;

    /** */
    int ApplyInverse(const Epetra_MultiVector& in, Epetra_MultiVector& out) const ;

    /** */
    double NormInf() const ;

    /** */
    const char* Label() const ;

    /** */
    bool UseTranspose() const {return useTranspose_;}

    /** */
    bool HasNormInf() const {return false;}

    /** */
    const Epetra_Comm& Comm() const {return *comm_;}

    /** */
    const Epetra_Map& OperatorDomainMap() const {return *domain_;}

    /** */
    const Epetra_Map& OperatorRangeMap() const {return *range_;}

    

  private:
    LinearOperator<double> A_;
    LinearSolver<double> solver_;
    bool useTranspose_;
    RCP<Epetra_Comm> comm_;
    RCP<const Epetra_Map> domain_;
    RCP<const Epetra_Map> range_;
    bool isNativeEpetra_;
    bool isCompoundEpetra_;
    string label_;
  };
}

#endif
